Learn R Programming

tectonicr (version 0.4.9)

PoR_coordinates: Coordinates of the Pole of Rotation Reference System

Description

Retrieve the PoR equivalent coordinates of an object

Usage

PoR_coordinates(x, PoR)

Value

PoR_coordinates() returns data.frame with the PoR coordinates (lat.PoR, lon.PoR).

Arguments

x

Can be either a "data.frame" containing lat and lon coordinates of a point in the geographical CRS or the lat.PoR, lon.PoR) of the point in the PoR CRS, a two-column matrix containing the lat and lon coordinates, a sf object, or a raster object.

PoR

Pole of Rotation. "data.frame" containing the geographical coordinates of the Euler pole

Examples

Run this code
data("nuvel1")
por <- subset(nuvel1, nuvel1$plate.rot == "na") # North America relative to Pacific plate
data("san_andreas")

# coordinates from sf object
san_andreas.por_sf <- PoR_coordinates(san_andreas, por)
head(san_andreas.por_sf)

# coordinates from data.frame
san_andreas.por_df <- PoR_coordinates(sf::st_drop_geometry(san_andreas), por)
head(san_andreas.por_df)

Run the code above in your browser using DataLab