Calculates bootstrapped estimates of the circular dispersion, its standard error and its confidence interval.
Usage
circular_dispersion_boot(
x,
y = NULL,
w = NULL,
w.y = NULL,
R = 1000,
conf.level = 0.95,
...
)Arguments
- x, y
vectors of numeric values in degrees.
length(y)is either1orlength(x)- w, w.y
(optional) Weights. A vector of positive numbers and of the same length as
x.w.yis the (optional) weight ofy.- R
positive integer. The number of bootstrap replicates (1000 by default).
- conf.level
Level of confidence: \((1 - \alpha \%)/100\). (
0.95by default).- ...
optional arguments passed to
boot::boot()
Value
list containing:
MLEthe maximum likelihood estimate of the circular dispersion
sdestandard error of MLE
CIlower and upper limit of the confidence interval of MLE
Examples
data("nuvel1")
PoR <- subset(nuvel1, nuvel1$plate.rot == "na")
sa.por <- PoR_shmax(san_andreas, PoR, "right")
circular_dispersion(sa.por$azi.PoR, y = 135, w = weighting(san_andreas$unc))
#> [1] 0.1384805
circular_dispersion_boot(sa.por$azi.PoR, y = 135, w = weighting(san_andreas$unc), R = 1000)
#> $MLE
#> [1] 0.2610566
#>
#> $sde
#> [1] 0.01132889
#>
#> $CI
#> [1] 0.2375632 0.2833176
#>