Learn R Programming

tectonicr (version 0.4.9)

circular_summary: Circular Summary Statistics

Description

Circular mean, standard deviation, variance, quasi-quantiles, mode, 95% confidence angle, standardized skewness and kurtosis

Usage

circular_summary(
  x,
  w = NULL,
  axial = TRUE,
  mode = FALSE,
  kappa = NULL,
  fisher.CI = FALSE,
  conf.level = 0.95,
  na.rm = FALSE
)

Value

named vector

Arguments

x

numeric vector. Values in degrees, for which the mean, median or standard deviation are required.

w

(optional) Weights. A vector of positive numbers, of the same length as x.

axial

logical. Whether the data are axial, i.e. pi-periodical (TRUE, the default) or directional, i.e. \(2 \pi\)-periodical (FALSE).

mode

logical. Whether the circular mode should be calculated or not.

kappa

numeric. von Mises distribution concentration parameter used for the circular mode. Will be estimated using est.kappa() if not provided.

fisher.CI

logical. Whether Fisher's or the default Mardia/Batchelet's confidence interval should be calculated.

conf.level

Level of confidence: \((1 - \alpha \%)/100\). (0.95 by default).

na.rm

logical value indicating whether NA values in x should be stripped before the computation proceeds.

See Also

circular_mean(), circular_sd(), circular_var(), circular_quantiles(), confidence_angle(), second_central_moment(), circular_mode()

Examples

Run this code
data("nuvel1")
PoR <- subset(nuvel1, nuvel1$plate.rot == "na")
sa.por <- PoR_shmax(san_andreas, PoR, "right")
circular_summary(sa.por$azi.PoR)
circular_summary(sa.por$azi.PoR, w = weighting(san_andreas$unc))

Run the code above in your browser using DataLab