- x
numeric. A vector of angles (in degrees) from which the estimate is to be computed.
- z
numeric. Angles where the density is estimated. If NULL equally
spaced angles are used according to the parameters from, to and n.
- bw, kappa, rho, sd, c
numeric. Smoothing bandwidth expressed as the concentration
parameter \(\kappa\) for the von Mises distribution, \(\rho\) for the
wrapped Cauchy distribution, or \(\sigma\) for the wrapped normal distribution.
Small and large values for the von Mises and wrapped normal/Cauchy distribution,
respectively, gives smooth density lines. If not specified, parameter will be estimated using
est.kappa() for the von Mises distribution, or set to \(p \exp(-1)\) and 1
for the wrapped Cauchy and wrapped Normal distribution (where \(p = 2\)
when axial=TRUE and 1 otherwise), respectively.
- weights
numeric. A vector of observation weights, of the same length as x,
to give individual observations weight in the density estimate. Should sum to 1;
a warning is issued if it doesn't (unless subdensity = TRUE). Defaults to
equal weight 1/length(x) per observation, matching stats::density().
- na.rm
logical; if TRUE, missing values are removed
from x. If FALSE any missing values cause an error.
- from, to
the left and right-most points of the grid at which the
density is to be estimated; the defaults are cut * bw outside
of range(x).
- n
integer. Number of equally spaced angles at which the density is
to be estimated.
- axial
Logical. Whether data are uniaxial (axial=FALSE)
or biaxial (TRUE, the default).
- kernel
character. The smoothing kernel to be used; one of "vonmises"
(the default), "wrappedcauchy", "wrappednormal, for the von Mises,
the wrapped Cauchy, and the wrapped Normal distribution.
- adjust
the bandwidth used is actually adjust*bw.
This makes it easy to specify values like ‘half the default’
bandwidth.
- subdensity
logical. If TRUE, suppress the "sum(weights) != 1" warning,
for when a deliberately partial (sub-)density is wanted, e.g. one group's
contribution to a shared total. See stats::density().