Learn R Programming

tectonicr (version 0.4.9)

cunif: The Circular Uniform Distribution

Description

Density, probability distribution function, quantiles, and random generation for the circular uniform distribution.

Usage

rcunif(n, axial = FALSE)

dcunif(theta, axial = FALSE, log = FALSE)

pcunif(theta, axial = FALSE, lower.tail = TRUE, log.p = FALSE)

qcunif(p, axial = FALSE, lower.tail = TRUE, log.p = FALSE)

Value

dcunif gives the density, pcunif gives the probability of circular uniform distribution function, rcunif generates random deviates (in degrees), and qcunif provides quantiles (in degrees).

Arguments

n

number of observations. If length(n) > 1, the length is taken to be the number required.

axial

logical. Whether the data are axial, i.e. \(\pi\)-periodical (TRUE, the default) or directional, i.e. \(2 \pi\)-periodical (FALSE).

theta

numeric. Angular value in degrees

log, log.p

logical; if TRUE, probabilities p are given as log(p).

lower.tail

logical; if TRUE (default), probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\).

p

numeric. Vector of probabilities with values in \([0,1]\).

See Also

wnorm, wcauchy, and vonmises

Examples

Run this code
set.seed(1)
x <- rcunif(5)

dcunif(x)
dcunif(x, axial = TRUE)

pcunif(x)
qcunif(c(.25, .5, .75))

Run the code above in your browser using DataLab