Stress field and wavelength analysis using circular dispersion (or other statistical estimators for dispersion)
kernel_dispersion(
x,
stat = c("dispersion", "nchisq", "rayleigh"),
grid = NULL,
lon_range = NULL,
lat_range = NULL,
gridsize = 2.5,
min_data = 3L,
max_data = Inf,
min_dist_threshold = 200,
dist_threshold = 0.1,
stat_threshold = Inf,
R_range = seq(100, 2000, 100),
...
)dispersion_grid(...)
sf object containing
longitude and latitude in degree
output of function defined in stat
The rearch radius in km.
Mean distance of datapoints per search radius
Number of data points in search radius
sf object containing
the observed \(\sigma_\text{Hmax}\) in degree
(optional) Uncertainties of ibserved SHmax in degree
(optional) Methods used for the determination of the direction of \(\sigma_\text{Hmax}\)
the predicted \(\sigma_\text{Hmax}\) in degree
The measurement of dispersion to be calculated. Either
"dispersion" (default), "nchisq", or "rayleigh" for circular
dispersion, normalized Chi-squared test statistic, or Rayleigh test
statistic.
(optional) Point object of class sf.
(optional) numeric vector specifying the minimum
and maximum longitudes and latitudes (ignored if grid is specified).
numeric. Target spacing of the regular grid in decimal
degree. Default is 2.5. (is ignored if grid is specified)
integer. If the number of observations within distance
R_range is less than min_data, a missing value NA will be generated.
Default is 3 for stress2grid() and 4 for stress2grid_stats().
integer. The number of nearest observations that should be
used for prediction, where "nearest" is defined in terms of the space of the
spatial locations. Default is Inf.
numeric. Distance threshold for smallest distance
of the prediction location to the next observation location.
Default is 200 km.
numeric. Distance weight to prevent overweight of data
nearby (0 to 1). Default is 0.1
numeric. Generates missing values when the kernel
stat value exceeds this threshold. Default is Inf.
numeric value or vector specifying the kernel half-width(s)
search radii,
i.e. the maximum distance from the prediction location to be used for
prediction (in km). Default is seq(50, 1000, 50). If combined with
max_data, both criteria apply.
arguments passed to stat functions weighted_rayleigh() or
circular_dispersion()
circular_dispersion(), norm_chisq(), weighted_rayleigh()
data("nuvel1")
PoR <- subset(nuvel1, nuvel1$plate.rot == "na")
san_andreas_por <- data2PoR(san_andreas, PoR)
san_andreas_por$prd <- 135
kernel_dispersion(san_andreas_por) |> head()
Run the code above in your browser using DataLab