Conversion between PoR to geographical coordinates of sf data
Source:R/coordinates.R
por_transformation_sf.RdTransform spatial objects from PoR to geographical coordinate reference system and vice versa.

R/coordinates.R
por_transformation_sf.RdTransform spatial objects from PoR to geographical coordinate reference system and vice versa.