Density, probability distribution function, quantiles, and random generation
for the circular normal distribution with mean \(\mu\) and kappa \(\kappa\).
qvm(p, mean, kappa, from = NULL, tol = .Machine$double.eps^(0.6), ...)
Value
dvm gives the density,
pvm gives the probability of the von Mises distribution function,
rvm generates random deviates (in degrees), and
qvm provides quantiles (in degrees).
Arguments
n
number of observations. If length(n) > 1, the length
is taken to be the number required.
mean
numeric. The mean vector in degrees.
kappa
numeric. Concentration parameter in the range \([0, Inf]\)
theta
numeric. Angular value in degrees
axial
logical. Whether the data are axial, i.e. \(\pi\)-periodical
(TRUE, the default) or directional, i.e. \(2 \pi\)-periodical (FALSE).
log
logical. If TRUE, probabilities p are given as \(\log(p)\).
from
if NULL is set to \(\mu-\pi\). This is the value from
which the pvm and qvm are evaluated. in degrees.
tol
numeric. The precision in evaluating the distribution function or the quantile.
p
numeric. Vector of probabilities with values in \([0,1]\).