Learn R Programming

tectonicr (version 0.4.9)

wcauchy: The Wrapped Cauchy Distribution

Description

Density, probability distribution function, quantiles, and random generation for the circular wrapped Cauchy distribution with mean \(\mu\) and rho \(\rho\)

Usage

rwcauchy(n, mean, rho)

dwcauchy(theta, mean, rho, axial = FALSE, log = FALSE)

pwcauchy( theta, mean, rho, axial = FALSE, from = NULL, lower.tail = TRUE, log.p = FALSE )

qwcauchy( p, mean, rho, axial = FALSE, from = NULL, lower.tail = TRUE, log.p = FALSE )

Value

dwcauchy gives the density, pwcauchy gives the probability of the wrapped Cauchy distribution function, rwcauchy generates random deviates (in degrees), and qrwcauchy provides quantiles (in degrees).

Arguments

n

number of observations. If length(n) > 1, the length is taken to be the number required.

mean

numeric. The mean vector in degrees.

rho

numeric. Concentration parameter in the range (0, 1)

theta

numeric. Angular value in degrees

axial

logical. Whether the data are axial, i.e. \(\pi\)-periodical (TRUE, the default) or directional, i.e. \(2 \pi\)-periodical (FALSE).

log

logical. If TRUE, probabilities p are given as \(\log(p)\).

from

if NULL is set to \(\mu-\pi\). This is the value from which the pvm and qvm are evaluated. in degrees.

lower.tail

logical; if TRUE (default), probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\).

log.p

logical. If TRUE, probabilities p are given as log(p).

p

numeric. Vector of probabilities with values in \([0,1]\).

See Also

cunif, wnorm, and vonmises

Examples

Run this code
set.seed(1)
x <- rwcauchy(5, mean = 90, rho = exp(-1))

dwcauchy(x, mean = 90, rho = exp(-1))
dwcauchy(x, mean = 90, rho = exp(-1), axial = TRUE)

pwcauchy(x, mean = 90, rho = exp(-1))
qwcauchy(c(.25, .5, .75), mean = 90, rho = exp(-1))

Run the code above in your browser using DataLab